@@ -35,6 +35,11 @@ __all__ = (
     "RxNormEntityCategoryType",
     "RxNormEntityTypeType",
     "RxNormTraitNameType",
+    "SNOMEDCTAttributeTypeType",
+    "SNOMEDCTEntityCategoryType",
+    "SNOMEDCTEntityTypeType",
+    "SNOMEDCTRelationshipTypeType",
+    "SNOMEDCTTraitNameType",
     "ServiceName",
 )
 
@@ -50,12 +55,15 @@ EntitySubTypeType = Literal[
     "DIRECTION",
     "DOSAGE",
     "DURATION",
+    "DX_NAME",
     "EMAIL",
     "FORM",
     "FREQUENCY",
     "GENERIC_NAME",
+    "ID",
     "IDENTIFIER",
     "NAME",
+    "PHONE_OR_FAX",
     "PROCEDURE_NAME",
     "PROFESSION",
     "QUALITY",
@@ -65,6 +73,7 @@ EntitySubTypeType = Literal[
     "STRENGTH",
     "SYSTEM_ORGAN_SITE",
     "TEST_NAME",
+    "TEST_UNIT",
     "TEST_UNITS",
     "TEST_VALUE",
     "TIME_EXPRESSION",
@@ -123,6 +132,7 @@ RelationshipTypeType = Literal[
     "ROUTE_OR_MODE",
     "STRENGTH",
     "SYSTEM_ORGAN_SITE",
+    "TEST_UNIT",
     "TEST_UNITS",
     "TEST_VALUE",
     "WITH_DOSAGE",
@@ -133,6 +143,15 @@ RxNormAttributeTypeType = Literal[
 RxNormEntityCategoryType = Literal["MEDICATION"]
 RxNormEntityTypeType = Literal["BRAND_NAME", "GENERIC_NAME"]
 RxNormTraitNameType = Literal["NEGATION"]
+SNOMEDCTAttributeTypeType = Literal[
+    "ACUITY", "DIRECTION", "QUALITY", "SYSTEM_ORGAN_SITE", "TEST_UNIT", "TEST_VALUE"
+]
+SNOMEDCTEntityCategoryType = Literal["ANATOMY", "MEDICAL_CONDITION", "TEST_TREATMENT_PROCEDURE"]
+SNOMEDCTEntityTypeType = Literal["DX_NAME", "PROCEDURE_NAME", "TEST_NAME", "TREATMENT_NAME"]
+SNOMEDCTRelationshipTypeType = Literal[
+    "ACUITY", "DIRECTION", "QUALITY", "SYSTEM_ORGAN_SITE", "TEST_UNITS", "TEST_VALUE"
+]
+SNOMEDCTTraitNameType = Literal["DIAGNOSIS", "NEGATION", "SIGN", "SYMPTOM"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -142,10 +161,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -160,6 +181,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -214,6 +236,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -235,6 +258,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -261,6 +285,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -274,6 +299,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -319,7 +345,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -348,11 +376,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -362,6 +392,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -419,5 +450,6 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
