@@ -27,6 +27,11 @@ from .literals import (
     RelationshipTypeType,
     RxNormAttributeTypeType,
     RxNormEntityTypeType,
+    SNOMEDCTAttributeTypeType,
+    SNOMEDCTEntityCategoryType,
+    SNOMEDCTEntityTypeType,
+    SNOMEDCTRelationshipTypeType,
+    SNOMEDCTTraitNameType,
 )
 
 if sys.version_info >= (3, 9):
@@ -41,6 +46,7 @@ else:
 
 __all__ = (
     "AttributeTypeDef",
+    "CharactersTypeDef",
     "ComprehendMedicalAsyncJobFilterTypeDef",
     "ComprehendMedicalAsyncJobPropertiesTypeDef",
     "DescribeEntitiesDetectionV2JobRequestRequestTypeDef",
@@ -51,6 +57,8 @@ __all__ = (
     "DescribePHIDetectionJobResponseTypeDef",
     "DescribeRxNormInferenceJobRequestRequestTypeDef",
     "DescribeRxNormInferenceJobResponseTypeDef",
+    "DescribeSNOMEDCTInferenceJobRequestRequestTypeDef",
+    "DescribeSNOMEDCTInferenceJobResponseTypeDef",
     "DetectEntitiesRequestRequestTypeDef",
     "DetectEntitiesResponseTypeDef",
     "DetectEntitiesV2RequestRequestTypeDef",
@@ -66,6 +74,8 @@ __all__ = (
     "InferICD10CMResponseTypeDef",
     "InferRxNormRequestRequestTypeDef",
     "InferRxNormResponseTypeDef",
+    "InferSNOMEDCTRequestRequestTypeDef",
+    "InferSNOMEDCTResponseTypeDef",
     "InputDataConfigTypeDef",
     "ListEntitiesDetectionV2JobsRequestRequestTypeDef",
     "ListEntitiesDetectionV2JobsResponseTypeDef",
@@ -75,12 +85,19 @@ __all__ = (
     "ListPHIDetectionJobsResponseTypeDef",
     "ListRxNormInferenceJobsRequestRequestTypeDef",
     "ListRxNormInferenceJobsResponseTypeDef",
+    "ListSNOMEDCTInferenceJobsRequestRequestTypeDef",
+    "ListSNOMEDCTInferenceJobsResponseTypeDef",
     "OutputDataConfigTypeDef",
     "ResponseMetadataTypeDef",
     "RxNormAttributeTypeDef",
     "RxNormConceptTypeDef",
     "RxNormEntityTypeDef",
     "RxNormTraitTypeDef",
+    "SNOMEDCTAttributeTypeDef",
+    "SNOMEDCTConceptTypeDef",
+    "SNOMEDCTDetailsTypeDef",
+    "SNOMEDCTEntityTypeDef",
+    "SNOMEDCTTraitTypeDef",
     "StartEntitiesDetectionV2JobRequestRequestTypeDef",
     "StartEntitiesDetectionV2JobResponseTypeDef",
     "StartICD10CMInferenceJobRequestRequestTypeDef",
@@ -89,6 +106,8 @@ __all__ = (
     "StartPHIDetectionJobResponseTypeDef",
     "StartRxNormInferenceJobRequestRequestTypeDef",
     "StartRxNormInferenceJobResponseTypeDef",
+    "StartSNOMEDCTInferenceJobRequestRequestTypeDef",
+    "StartSNOMEDCTInferenceJobResponseTypeDef",
     "StopEntitiesDetectionV2JobRequestRequestTypeDef",
     "StopEntitiesDetectionV2JobResponseTypeDef",
     "StopICD10CMInferenceJobRequestRequestTypeDef",
@@ -97,6 +116,8 @@ __all__ = (
     "StopPHIDetectionJobResponseTypeDef",
     "StopRxNormInferenceJobRequestRequestTypeDef",
     "StopRxNormInferenceJobResponseTypeDef",
+    "StopSNOMEDCTInferenceJobRequestRequestTypeDef",
+    "StopSNOMEDCTInferenceJobResponseTypeDef",
     "TraitTypeDef",
     "UnmappedAttributeTypeDef",
 )
@@ -118,6 +139,14 @@ AttributeTypeDef = TypedDict(
     total=False,
 )
 
+CharactersTypeDef = TypedDict(
+    "CharactersTypeDef",
+    {
+        "OriginalTextCharacters": int,
+    },
+    total=False,
+)
+
 ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobFilterTypeDef",
     {
@@ -210,6 +239,21 @@ DescribeRxNormInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
+DescribeSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "DescribeSNOMEDCTInferenceJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+DescribeSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
+    "DescribeSNOMEDCTInferenceJobResponseTypeDef",
+    {
+        "ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DetectEntitiesRequestRequestTypeDef = TypedDict(
     "DetectEntitiesRequestRequestTypeDef",
     {
@@ -366,6 +410,25 @@ InferRxNormResponseTypeDef = TypedDict(
     },
 )
 
+InferSNOMEDCTRequestRequestTypeDef = TypedDict(
+    "InferSNOMEDCTRequestRequestTypeDef",
+    {
+        "Text": str,
+    },
+)
+
+InferSNOMEDCTResponseTypeDef = TypedDict(
+    "InferSNOMEDCTResponseTypeDef",
+    {
+        "Entities": List["SNOMEDCTEntityTypeDef"],
+        "PaginationToken": str,
+        "ModelVersion": str,
+        "SNOMEDCTDetails": "SNOMEDCTDetailsTypeDef",
+        "Characters": "CharactersTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredInputDataConfigTypeDef = TypedDict(
     "_RequiredInputDataConfigTypeDef",
     {
@@ -469,6 +532,27 @@ ListRxNormInferenceJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListSNOMEDCTInferenceJobsRequestRequestTypeDef = TypedDict(
+    "ListSNOMEDCTInferenceJobsRequestRequestTypeDef",
+    {
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListSNOMEDCTInferenceJobsResponseTypeDef = TypedDict(
+    "ListSNOMEDCTInferenceJobsResponseTypeDef",
+    {
+        "ComprehendMedicalAsyncJobPropertiesList": List[
+            "ComprehendMedicalAsyncJobPropertiesTypeDef"
+        ],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredOutputDataConfigTypeDef = TypedDict(
     "_RequiredOutputDataConfigTypeDef",
     {
@@ -550,6 +634,70 @@ RxNormTraitTypeDef = TypedDict(
     total=False,
 )
 
+SNOMEDCTAttributeTypeDef = TypedDict(
+    "SNOMEDCTAttributeTypeDef",
+    {
+        "Category": SNOMEDCTEntityCategoryType,
+        "Type": SNOMEDCTAttributeTypeType,
+        "Score": float,
+        "RelationshipScore": float,
+        "RelationshipType": SNOMEDCTRelationshipTypeType,
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Text": str,
+        "Traits": List["SNOMEDCTTraitTypeDef"],
+        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
+    },
+    total=False,
+)
+
+SNOMEDCTConceptTypeDef = TypedDict(
+    "SNOMEDCTConceptTypeDef",
+    {
+        "Description": str,
+        "Code": str,
+        "Score": float,
+    },
+    total=False,
+)
+
+SNOMEDCTDetailsTypeDef = TypedDict(
+    "SNOMEDCTDetailsTypeDef",
+    {
+        "Edition": str,
+        "Language": str,
+        "VersionDate": str,
+    },
+    total=False,
+)
+
+SNOMEDCTEntityTypeDef = TypedDict(
+    "SNOMEDCTEntityTypeDef",
+    {
+        "Id": int,
+        "Text": str,
+        "Category": SNOMEDCTEntityCategoryType,
+        "Type": SNOMEDCTEntityTypeType,
+        "Score": float,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Attributes": List["SNOMEDCTAttributeTypeDef"],
+        "Traits": List["SNOMEDCTTraitTypeDef"],
+        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
+    },
+    total=False,
+)
+
+SNOMEDCTTraitTypeDef = TypedDict(
+    "SNOMEDCTTraitTypeDef",
+    {
+        "Name": SNOMEDCTTraitNameType,
+        "Score": float,
+    },
+    total=False,
+)
+
 _RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
     "_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef",
     {
@@ -690,6 +838,41 @@ StartRxNormInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": Literal["en"],
+    },
+)
+_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartSNOMEDCTInferenceJobRequestRequestTypeDef(
+    _RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef,
+    _OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef,
+):
+    pass
+
+
+StartSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
+    "StartSNOMEDCTInferenceJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 StopEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
     "StopEntitiesDetectionV2JobRequestRequestTypeDef",
     {
@@ -750,6 +933,21 @@ StopRxNormInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
+StopSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "StopSNOMEDCTInferenceJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+StopSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
+    "StopSNOMEDCTInferenceJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 TraitTypeDef = TypedDict(
     "TraitTypeDef",
     {
